multiformats.multiaddr.err
==========================

.. automodule:: multiformats.multiaddr.err

MultiaddrKeyError
-----------------

.. autoclass:: multiformats.multiaddr.err.MultiaddrKeyError
    :members:

MultiaddrValueError
-------------------

.. autoclass:: multiformats.multiaddr.err.MultiaddrValueError
    :members:
